==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'לכתבות הבאות בלבד(ללא פעולה בבסיס (הנתונים',
	'bouton_radio_articles_tous' => 'לכל הכתבות ללא יוצא מן הכלל',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'לכל הכתבות, חוץ מאלה עם הפורומים הפסולים',
	'bouton_radio_enregistrement_obligatoire' => 'שמירה הכרחית (ה
 משתמשים צריכים להיות מנויים על ידי מסירת כתובת המייל שלהם לפני
 שהם יוכלו לשלוח את תרומותיהם).',
	'bouton_radio_moderation_priori' => 'בוררות מוקדמת (ה
 תורמים מופיעים בציבור רק לאחר שהם מאושרים על ידי
 האדמיניסטרטורים).', # MODIF
	'bouton_radio_modere_abonnement' => 'צמצום על ידי מנוי',
	'bouton_radio_modere_posteriori' => 'צמצום לאחר מכן', # MODIF
	'bouton_radio_modere_priori' => 'צמצום מראש', # MODIF
	'bouton_radio_publication_immediate' => 'פרסום מיידי של הודעות
 (התרומות מופיעות מרגע שליחתן, האדמיניסטרטורים יכולים
 למחקן לאחר מכן).',

	// D
	'documents_interdits_forum' => 'בשלב זה נאסר בפורום',

	// F
	'form_pet_message_commentaire' => 'יש לך תגובה או הודעה ?',
	'forum' => 'פורום',
	'forum_acces_refuse' => 'אין לך גישה לפורומים האלה יותר.',
	'forum_attention_dix_caracteres' => '<b>שים לב!</b> ההודעה שלך צריכה לכלול לפחות עשר אותיות.',
	'forum_attention_trois_caracteres' => '<b>שים לב!</b> הנושא שלך צריך לכלול לפחות שלוש אותיות.',
	'forum_attention_trop_caracteres' => '<b>זהירות !</b> הודעתך ארוכה מדי (@compte@ caractères) : על מנת להישמר. היא צריכה לכולל פחות מ@max@ אותיות.', # MODIF
	'forum_avez_selectionne' => 'הינך בחרת:',
	'forum_cliquer_retour' => 'נא להקליק  <a href=\'@retour_forum@\'>כאן</a> כדי להמשיך.',
	'forum_forum' => 'פורום',
	'forum_info_modere' => 'הפורום מתצמצם מראש: התרומה שלך תופיע רק אחרי אישור מנהלי האתר.', # MODIF
	'forum_lien_hyper' => '<b>קישור</b> (אופציונלי)', # MODIF
	'forum_message_definitif' => 'הודעה סופית : שלח לאתר',
	'forum_message_trop_long' => 'ההודעה שלך ארוכה מדי. אורך מקסימלי של הודעה צריך להיות 20000 אותיות.', # MODIF
	'forum_ne_repondez_pas' => 'אל תחזיר תשובה לדוא"ל הזה אבל בפורום בכתובת הבאה:', # MODIF
	'forum_page_url' => '(אם הודעתך מופנית למאמר שמפורסם ברשת או לדף המספק מידע נוסף, בבקשה רשום את הכותרת של הדף והכתובת הכללית שלו.)',
	'forum_poste_par' => 'הודעה נשלחה @parauteur@ העוסקת בכתבתך « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>מי את / אתה?</b> (אופציונלי)', # MODIF
	'forum_texte' => 'טקסט של הודעתך :', # MODIF
	'forum_titre' => 'נושא:', # MODIF
	'forum_url' => 'כתובת כללית:', # MODIF
	'forum_valider' => 'תן תוקף לבחירה הזאת',
	'forum_voir_avant' => 'הצגה מוקדמת של ההודעה לפני פרסומה', # MODIF
	'forum_votre_email' => 'כתובת הדוא"ל שלך:', # MODIF
	'forum_votre_nom' => ':(השם שלך (או הכינוי', # MODIF
	'forum_vous_enregistrer' => 'כדי להשתתף
  לפורום זה, ההרשמה מחויבת
  נא להכנסי את הפרטים האישים
  שנשלחו לך. אם אינך מרשם, עליך',
	'forum_vous_inscrire' => 'להירשם',

	// I
	'icone_poster_message' => 'כתוב הודעה',
	'icone_suivi_forum' => 'מעקב אחר הפורום הכללי: @nb_forums@ תרומה/תרומות',
	'icone_suivi_forums' => 'מעקב/ניהול פורומים',
	'icone_supprimer_message' => 'מחק הודעה זו',
	'icone_valider_message' => 'תן תוקף להודעה זו',
	'info_activer_forum_public' => 'על מנת להפעיל את הפורומים הציבוריים, אנא בחר את מצב
 הבוררות שלהם כברירת מחדל:</i>', # MODIF
	'info_appliquer_choix_moderation' => ':יישם את הבחירה הזו של צמצום',
	'info_desactiver_forum_public' => 'ביטול פעילות הפורומים
הציבוריים. הפורומים הציבוריים יופעלו רק אחרי החלטה
על המאמרם. לא יהיה אפשר להפעיל אותם על המדורים, על המבזקים וכו’.',
	'info_envoi_forum' => 'שלח פורומים למחברי המאמרים',
	'info_fonctionnement_forum' => ':פעולת הפורום',
	'info_gauche_suivi_forum_2' => 'ה<i>forums follow-up</i> דף הוא לא אמצעי ניהול של אתרך (לא דיון או עריכה). הוא מציג את כל התרומות של הפורום הציבורי של המאמר הזה ומאפשר לך לנהל את התרומות האלה', # MODIF
	'info_liens_syndiques_3' => 'פורומים',
	'info_liens_syndiques_4' => ' ',
	'info_liens_syndiques_5' => 'פורום',
	'info_liens_syndiques_6' => ' ',
	'info_liens_syndiques_7' => '.מחכה למתן תוקף חוקי',
	'info_mode_fonctionnement_defaut_forum_public' => 'פעולה ברירת מחדל של פורומים ציבוריים',
	'info_pas_de_forum' => 'אין פורום',

	// L
	'lien_reponse_breve_2' => 'תגובה למבזק',

	// O
	'onglet_messages_internes' => 'הודעות פנימיות',
	'onglet_messages_publics' => 'הודעות ציבוריות',
	'onglet_messages_vide' => 'הודעות בלי טקסט',

	// R
	'repondre_message' => 'הוספת תגובה להודעה',

	// S
	'statut_original' => 'מקורי',

	// T
	'titre_forum' => 'פורום'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'לכתבות הבאות בלבד(ללא פעולה בבסיס (הנתונים',
	'bouton_radio_articles_tous' => 'לכל הכתבות ללא יוצא מן הכלל',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'לכל הכתבות, חוץ מאלה עם הפורומים הפסולים',
	'bouton_radio_enregistrement_obligatoire' => 'שמירה הכרחית (ה
 משתמשים צריכים להיות מנויים על ידי מסירת כתובת המייל שלהם לפני
 שהם יוכלו לשלוח את תרומותיהם).',
	'bouton_radio_moderation_priori' => 'בוררות מוקדמת (ה
 תורמים מופיעים בציבור רק לאחר שהם מאושרים על ידי
 האדמיניסטרטורים).', # MODIF
	'bouton_radio_modere_abonnement' => 'צמצום על ידי מנוי',
	'bouton_radio_modere_posteriori' => 'צמצום לאחר מכן', # MODIF
	'bouton_radio_modere_priori' => 'צמצום מראש', # MODIF
	'bouton_radio_publication_immediate' => 'פרסום מיידי של הודעות
 (התרומות מופיעות מרגע שליחתן, האדמיניסטרטורים יכולים
 למחקן לאחר מכן).',

	// D
	'documents_interdits_forum' => 'בשלב זה נאסר בפורום',

	// F
	'form_pet_message_commentaire' => 'יש לך תגובה או הודעה ?',
	'forum' => 'פורום',
	'forum_acces_refuse' => 'אין לך גישה לפורומים האלה יותר.',
	'forum_attention_dix_caracteres' => '<b>שים לב!</b> ההודעה שלך צריכה לכלול לפחות עשר אותיות.',
	'forum_attention_trois_caracteres' => '<b>שים לב!</b> הנושא שלך צריך לכלול לפחות שלוש אותיות.',
	'forum_attention_trop_caracteres' => '<b>זהירות !</b> הודעתך ארוכה מדי (@compte@ caractères) : על מנת להישמר. היא צריכה לכולל פחות מ@max@ אותיות.', # MODIF
	'forum_avez_selectionne' => 'הינך בחרת:',
	'forum_cliquer_retour' => 'נא להקליק  <a href=\'@retour_forum@\'>כאן</a> כדי להמשיך.',
	'forum_forum' => 'פורום',
	'forum_info_modere' => 'הפורום מתצמצם מראש: התרומה שלך תופיע רק אחרי אישור מנהלי האתר.', # MODIF
	'forum_lien_hyper' => '<b>קישור</b> (אופציונלי)', # MODIF
	'forum_message_definitif' => 'הודעה סופית : שלח לאתר',
	'forum_message_trop_long' => 'ההודעה שלך ארוכה מדי. אורך מקסימלי של הודעה צריך להיות 20000 אותיות.', # MODIF
	'forum_ne_repondez_pas' => 'אל תחזיר תשובה לדוא"ל הזה אבל בפורום בכתובת הבאה:', # MODIF
	'forum_page_url' => '(אם הודעתך מופנית למאמר שמפורסם ברשת או לדף המספק מידע נוסף, בבקשה רשום את הכותרת של הדף והכתובת הכללית שלו.)',
	'forum_poste_par' => 'הודעה נשלחה @parauteur@ העוסקת בכתבתך « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>מי את / אתה?</b> (אופציונלי)', # MODIF
	'forum_texte' => 'טקסט של הודעתך :', # MODIF
	'forum_titre' => 'נושא:', # MODIF
	'forum_url' => 'כתובת כללית:', # MODIF
	'forum_valider' => 'תן תוקף לבחירה הזאת',
	'forum_voir_avant' => 'הצגה מוקדמת של ההודעה לפני פרסומה', # MODIF
	'forum_votre_email' => 'כתובת הדוא"ל שלך:', # MODIF
	'forum_votre_nom' => ':(השם שלך (או הכינוי', # MODIF
	'forum_vous_enregistrer' => 'כדי להשתתף
  לפורום זה, ההרשמה מחויבת
  נא להכנסי את הפרטים האישים
  שנשלחו לך. אם אינך מרשם, עליך',
	'forum_vous_inscrire' => 'להירשם',

	// I
	'icone_poster_message' => 'כתוב הודעה',
	'icone_suivi_forum' => 'מעקב אחר הפורום הכללי: @nb_forums@ תרומה/תרומות',
	'icone_suivi_forums' => 'מעקב/ניהול פורומים',
	'icone_supprimer_message' => 'מחק הודעה זו',
	'icone_valider_message' => 'תן תוקף להודעה זו',
	'info_activer_forum_public' => 'על מנת להפעיל את הפורומים הציבוריים, אנא בחר את מצב
 הבוררות שלהם כברירת מחדל:</i>', # MODIF
	'info_appliquer_choix_moderation' => ':יישם את הבחירה הזו של צמצום',
	'info_desactiver_forum_public' => 'ביטול פעילות הפורומים
הציבוריים. הפורומים הציבוריים יופעלו רק אחרי החלטה
על המאמרם. לא יהיה אפשר להפעיל אותם על המדורים, על המבזקים וכו’.',
	'info_envoi_forum' => 'שלח פורומים למחברי המאמרים',
	'info_fonctionnement_forum' => ':פעולת הפורום',
	'info_gauche_suivi_forum_2' => 'ה<i>forums follow-up</i> דף הוא לא אמצעי ניהול של אתרך (לא דיון או עריכה). הוא מציג את כל התרומות של הפורום הציבורי של המאמר הזה ומאפשר לך לנהל את התרומות האלה', # MODIF
	'info_liens_syndiques_3' => 'פורומים',
	'info_liens_syndiques_4' => ' ',
	'info_liens_syndiques_5' => 'פורום',
	'info_liens_syndiques_6' => ' ',
	'info_liens_syndiques_7' => '.מחכה למתן תוקף חוקי',
	'info_mode_fonctionnement_defaut_forum_public' => 'פעולה ברירת מחדל של פורומים ציבוריים',
	'info_pas_de_forum' => 'אין פורום',

	// L
	'lien_reponse_breve_2' => 'תגובה למבזק',

	// O
	'onglet_messages_internes' => 'הודעות פנימיות',
	'onglet_messages_publics' => 'הודעות ציבוריות',
	'onglet_messages_vide' => 'הודעות בלי טקסט',

	// R
	'repondre_message' => 'הוספת תגובה להודעה',

	// S
	'statut_original' => 'מקורי',

	// T
	'titre_forum' => 'פורום',
];
